#!/usr/bin/python
import os
import pwd
import grp
import subprocess

from shutil import rmtree
from charmhelpers.core.hookenv import log

def createPropertyElement(name, value):
    import xml.etree.ElementTree as ET
    propertyE = ET.Element("property")
    eName = ET.Element("name")
    eName.text = name
    propertyE.append(eName)
    eValue = ET.Element("value")
    eValue.text = value
    propertyE.append(eValue)
    return propertyE

def setHadoopConfigXML (xmlfileNamePath, name, value):
    import xml.dom.minidom as minidom
    print("==> setHadoopConfigXML ","INFO")
    import xml.etree.ElementTree as ET
    found = False
    with open(xmlfileNamePath,'rb+') as f:    
        root = ET.parse(f).getroot()
        proList = root.findall("property")
        for p in proList:
            if found:
                break
            cList = p.getchildren()
            for c in cList:
                if c.text == name:
                    p.find("value").text = value
                    found = True
                    break

        f.seek(0)
        if not found:            
            root.append(createPropertyElement(name, value))
            f.write((minidom.parseString(ET.tostring(root, encoding='UTF-8'))).toprettyxml(indent="\t"))
        else:
            f.write(ET.tostring(root, encoding='UTF-8'))
        f.truncate()

def setDirPermission(path, owner, group, access):
    log("==> setDirPermission")
    if os.path.isdir(path):
        rmtree(path)
    os.makedirs( path)
    os.chmod(path, access)
    chownRecursive(path, owner, group)

def chownRecursive(path, owner, group):
    print ("==> chownRecursive ")
    uid = pwd.getpwnam(owner).pw_uid
    gid = grp.getgrnam(group).gr_gid
    os.chown(path, uid, gid)
    for root, dirs, files in os.walk(path):
        for momo in dirs:
            os.chown(os.path.join(root, momo), uid, gid)
        for momo in files:
            os.chown(os.path.join(root, momo), uid, gid)
            
def chmodRecursive(path, mode):
    for r,d,f in os.walk(path):
        os.chmod( r , mode)
            
def wgetPkg(pkgName, crypType):
    log("==> wgetPkg ")
    crypFileName= pkgName+'.'+crypType    
    cmd = 'wget '+pkgName
    subprocess.call(cmd.split())
    if crypType:
        cmd = ['wget', crypFileName]
        subprocess.call(cmd)
    #TODO -- cryption validation
     
def append_bashrc(line):
    log("==> append_bashrc","INFO")
    with open(os.path.join(os.path.sep, 'home','ubuntu','.bashrc'),'a') as bf:
        bf.writelines(line)
        
def fileSetKV(filePath, key, value):
    log ("===> fileSetKV ({}, {}, {})".format(filePath, key, value))
    found = False
    with open(filePath) as f:
        contents = f.readlines()
        for l in range(0, len(contents)):
            if contents[l].startswith(key):
                contents[l] = key+value+"\n"
                found = True
    if not found:
        log ("*** Key={} not found, adding key+value= {}".format(key,value))
        contents.append(key+value+"\n")         
    with open(filePath, 'wb') as f:
        f.writelines(contents)

def fileRemoveKey(filePath, key):
    log ("===> fileRemoveK ({}, {})".format(filePath, key))
    found = False
    with open(filePath) as f:
        contents = f.readlines()
        for l in range(0, len(contents)):
            if contents[l].startswith(key):
                contents.pop(l)
                found = True
    if found:
        with open(filePath, 'wb') as f:
            f.writelines(contents)
       
def setHadoopEnvVarFromFile(scriptName):
    log("==> setHadoopEnvVarFromFile","INFO")
    with open(scriptName) as f:
        lines = f.readlines()
        for l in lines:
            if l.startswith("#") or l == '\n':
                continue
            else:
                ll = l.split("=")
                m = ll[0]+" = "+ll[1].strip().strip(';').strip("\"").strip()
                log ("==> {} ".format("\""+m+"\""))
                os.environ[ll[0]] = ll[1].strip().strip(';').strip("\"").strip()
                
def is_jvm_service_active(processname):
    cmd=["jps"]
    p = subprocess.Popen(cmd, stdout=subprocess.PIPE)
    out, err = p.communicate()
    if err == None and str(out).find(processname) != -1:
        return True
    else:
        return False